@@ -1,5 +1,20 @@
 package Parp::Blacklist;
 
+=head1 NAME
+
+Parp::Blacklist - Look up IP addresses on an internet blacklist via DNS
+
+=head1 SYNOPSIS
+
+Used internally; see L<Parp::Mail::Tests::Header>.
+
+=head1 DESCRIPTION
+
+Contains internal routines for determining whether IP addresses are
+blacklisted.
+
+=cut
+
 use strict;
 use warnings;
 
@@ -21,16 +36,16 @@ sub blacklist_lookup {
   my $TXT = '';
 
   if (Net::DNS::Resolver->can('new')) {
-    my $resolver = Net::DNS::Resolver->new();
+    my $resolver = Net::DNS::Resolver->new;
     my $reply = $resolver->query($name, "TXT");
     if ($reply) {
-      foreach my $rr ($reply->answer()) {
-        next unless $rr->type() eq "TXT";
-        $TXT = $rr->txtdata();
+      foreach my $rr ($reply->answer) {
+        next unless $rr->type eq "TXT";
+        $TXT = $rr->txtdata;
       }
-#      print "string: ", $reply->string(), "\n";
+#      print "string: ", $reply->string, "\n";
     } else {
-      my $error = $resolver->errorstring();
+      my $error = $resolver->errorstring;
       print "lookup of $name failed: $error\n"
         unless $error eq 'NOERROR'; # huh?
     }
