@@ -1,5 +1,21 @@
 package Parp::IdCache;
 
+=head1 NAME
+
+Parp::IdCache - message ID cache management 
+
+=head1 SYNOPSIS
+
+Used internally.
+
+=head1 DESCRIPTION
+
+This module provides routines for managing the database of recently
+delivered message IDs.  The database gets used when duplicate
+avoidance is turned on via the C<-d> option (see L<Parp::Options>).
+
+=cut
+
 use strict;
 use warnings;
 
@@ -15,9 +31,9 @@ our@EXPORT_OK = qw(is_duplicate);
 my @dup_ids = ();
 
 sub init {
-  if (config->id_cache()) {
+  if (config->id_cache) {
     lock_ident('IdCache');
-    tie @dup_ids, 'DB_File', config->id_cache(), O_CREAT | O_RDWR, 0600,
+    tie @dup_ids, 'DB_File', config->id_cache, O_CREAT | O_RDWR, 0600,
       $DB_RECNO;
   }
 }
@@ -40,7 +56,7 @@ sub add_id {
   my ($id) = @_;
   
   push @dup_ids, $id;
-  shift @dup_ids if @dup_ids > config->max_cache_ids();
+  shift @dup_ids if @dup_ids > config->max_cache_ids;
 }
 
 1;
