@@ -12,13 +12,13 @@ use base 'Parp::Filter';
 ## User-defined filtering routines.
 ##
 ## They are invoked as methods, so the first parameter is always the
-## Mail::Filterable object, which contains all the information you
+## Parp::Mail object, which contains all the information you
 ## would normally need to perform standard tests on it.  For example,
-## if $m is the object, $m->{subject} is the subject line, and
+## if $m is the object, $m->subject is the subject line, and
 ## $m->matches('ftc', $re) is a method which returns true if the regexp
 ## $re matches any of the e-mail addresses found in the From, To, Cc
-## (or X-Mailing-List) headers.  See Mail::Filterable::new() in the
-## main program for all available data.
+## (or X-Mailing-List) headers.  See the Parp::Mail manual page for
+## more information.
 ##
 ## Once you have performed tests and determined what action you want
 ## to take for a given e-mail, there are some useful methods available
@@ -31,50 +31,49 @@ use base 'Parp::Filter';
 ##   $m->deliver_to_inbox('bar');             # deliver to inbox `bar'
 ##   $m->pipe_forward('command arg1 arg2');   # pipe mail | command arg1 arg2
 ##
-## Return values are also important; see the filter() and
-## Mail::Filterable::categorize() routines in the main program to
-## understand how they affect filtering.
+## Return values are also important; see the filter() and categorize()
+## routines in Parp::Filter to understand how they affect filtering.
 ##
 
 
 #
-# is_special()
+# is_special_case()
 #
 # Handles special cases before virtually any other filtering
 # occurs.  Should return 'IS_SPECIAL' in cases where you want
 # to take all appropriate action yourself (e.g. delivery/forwarding).
 # Other return values have the normal meaning; for more details
-# see Mail::Filterable::categorize() in the main program.
+# see Parp::Filter::categorize().
 #
 
-sub is_special {
+sub is_special_case {
   my $self = shift;
   my ($m) = @_;
 
-  if ($m->{to} =~ /\b(adam-.*test.*\@thelonious\.new\.ox\.ac\.uk)\b/i) {
+  if ($m->to =~ /\b(adam-.*test.*\@thelonious\.new\.ox\.ac\.uk)\b/i) {
     $m->accept_mail('test mail', $1);
     $m->deliver_to_inbox('test');
     return 'IS_SPECIAL';
   }
 
-  if ($m->{to} =~ /\b(adam-.*auto.*\@thelonious\.new\.ox\.ac\.uk)\b/i) {
+  if ($m->to =~ /\b(adam-.*auto.*\@thelonious\.new\.ox\.ac\.uk)\b/i) {
     $m->accept_mail('auto-reply', $1);
     $m->deliver_to_inbox('autoreply');
     return 'IS_SPECIAL';
   }
 
-  if ($m->{to} =~ /\b(adam-cuteftp\@thelonious\.new\.ox\.ac\.uk)\b/i) {
+  if ($m->to =~ /\b(adam-cuteftp\@thelonious\.new\.ox\.ac\.uk)\b/i) {
     $m->ditch_mail('obsolete address', $1);
     return 'IS_SPECIAL';
   }
 
-  if ($m->{to} =~ /\b(adam-.*\@thelonious\.new\.ox\.ac\.uk|.*\@adamspiers.org)\b/i) {
+  if ($m->to =~ /\b(adam-.*\@thelonious\.new\.ox\.ac\.uk|.*\@adamspiers.org)\b/i) {
     $m->deliver_to_inbox('alt_addresses');
   }
 
   if (($m->matches('ftc', qr/buzzaway\.com\b/i))[0]) {
     $m->accept_mail('buzz spam');
-    $m->deliver_mail();
+    $m->deliver_to_main;
     return 'IS_SPECIAL';
   }
 
@@ -89,7 +88,7 @@ sub is_special {
     return 'IS_SPECIAL';
   }
 
-  if ($m->{to} =~ /solo string mailing list/i) {
+  if ($m->to =~ /solo string mailing list/i) {
     $m->accept_mail('solo string');
     $m->deliver_to_inbox('solo_string');
     return 'IS_SPECIAL';
@@ -152,36 +151,36 @@ sub is_special {
     return 'IS_SPECIAL';
   }
 
-  if ($m->{from} =~ /(nobody|jobs|subscriber\.email)\@.*jobserve\.com/i) {
+  if ($m->from =~ /(nobody|jobs|subscriber\.email)\@.*jobserve\.com/i) {
     $m->pipe_forward("$ENV{HOME}/bin/jobserve");
     return 'IS_SPECIAL';
   }
   
-  if ($m->{from} =~ /(jobs-filtered)\@jobserve\.com/i) {
+  if ($m->from =~ /(jobs-filtered)\@jobserve\.com/i) {
     $m->accept_mail('jobserve jobs (filtered)');
     $m->deliver_to_inbox('jobs-filtered');
     return 'IS_SPECIAL';
   }
   
-  if ($m->{subject} =~ /headlines/i and
+  if ($m->subject =~ /headlines/i and
       ($m->matches('ftc', qr/slashdot\.org/))[0]) {
     $m->accept_mail('slashdot daily news');
     $m->deliver_to_inbox('slashdot');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('from_addrs', qr/\@.*\.london\.guideguide\.com/))[0]) {
+  if (($m->matches('froms', qr/\@.*\.london\.guideguide\.com/))[0]) {
     $m->accept_mail('guideguide intranet');
     return 'IS_SPECIAL';
   }
 
   if (  
-        ($m->matches('from_addrs', config->me()))[0]           &&
-      ! ($m->matches('from_addrs', qr/auto|test/))[0] &&
-        $m->{mailer}   !~ /[Mm]utt|Eudora .* for PalmOS/     &&
-        $m->{reply_to} !~ /adam\@spiers\.net/                &&
-        $m->{to}       !~ /cvs-notify|topica\.com|gimp-perl/ &&
-        $m->{sender}   !~ /nobody\@.*guideguide\.com/ 
+        ($m->matches('froms', config->me))[0]           &&
+      ! ($m->matches('froms', qr/auto|test/))[0] &&
+        $m->mailer   !~ /[Mm]utt|Eudora .* for PalmOS/     &&
+        $m->reply_to !~ /adam\@spiers\.net/                &&
+        $m->to       !~ /cvs-notify|topica\.com|gimp-perl/ &&
+        $m->sender   !~ /nobody\@.*guideguide\.com/ 
      )
   {
     $m->reject_junk_mail('not /really/ from me');
@@ -189,7 +188,7 @@ sub is_special {
   }
 
   if (($m->matches('ftc', qr/activesw\.com/i))[0] &&
-      $m->{subject} =~ /qstat/i) {
+      $m->subject =~ /qstat/i) {
     $m->accept_mail('qstat');
     $m->deliver_to_inbox('qstat');
     return 'IS_SPECIAL';
@@ -208,11 +207,11 @@ sub is_special {
 
   if (($m->matches('ftc', qr/wstearns\@pobox\.com/i))[0]) {
     $m->accept_mail('buildkernel');
-    $m->deliver_mail();
+    $m->deliver_to_main;
     return 'IS_SPECIAL';
   }
 
-  if ($m->{to} =~ /\bIBM\b.*\bSupport Customer/) {
+  if ($m->to =~ /\bIBM\b.*\bSupport Customer/) {
     $m->accept_mail('IBM support');
     $m->deliver_to_inbox('ibm-support');
     return 'IS_SPECIAL';
@@ -256,25 +255,25 @@ sub is_special {
     return 'IS_SPECIAL';
   }
 
-  if ($m->{from} =~ /Member.Update/i &&
-      $m->{from} =~ /MyFamily/i) {
+  if ($m->from =~ /Member.Update/i &&
+      $m->from =~ /MyFamily/i) {
     $m->ditch_mail('MyFamily member update');
     return 'IS_SPECIAL';
   }
 
-  if ($m->{from} =~ /news\@mail\.com/) {
+  if ($m->from =~ /news\@mail\.com/) {
     $m->ditch_mail('mail.com crap');
     return 'IS_SPECIAL';
   }
 
-  if ($m->{from} =~ /announcement.*\@mail\.com/i) {
+  if ($m->from =~ /announcement.*\@mail\.com/i) {
     $m->accept_mail('mail.com announcement');
-    $m->deliver_mail();
+    $m->deliver_to_main;
     return 'IS_SPECIAL';
   }
 
-  if ($m->{from} =~ /apeleg\@interjazz\.com/ &&
-      $m->{subject} =~ /InterJazz mailing list/) {
+  if ($m->from =~ /apeleg\@interjazz\.com/ &&
+      $m->subject =~ /InterJazz mailing list/) {
     $m->accept_mail('interjazz');
     $m->deliver_to_inbox('interjazz');
     return 'IS_SPECIAL';
@@ -312,6 +311,9 @@ sub lists {
    'alsa-devel'       => { RE => '%s.*alsa-project\.org' },
    'alsa-user'        => { RE => '%s.*alsa-project\.org' },
    'apmd-list'        => { RE => '%s.*worldvisions\.ca' },
+   'arch-announce'    => { RE => '%s.*regexps\.com' },
+   'arch-users'       => { RE => '%s.*regexps\.com' },
+   'arch-dev'         => { RE => '%s.*regexps\.com' },
    'bashprompt'       => { RE => 'bash.*current\.nu' },
    'buggies'          => { RE => '%s@landfill\.tequilarista\.org' },
    'fetchmail'        => { RE => '%s-friends.*@lists\.ccil\.org' },
@@ -391,7 +393,7 @@ sub is_list_mail {
   my $rv = deliver_gg_stuff($m);
   return 1 if $rv eq 'NEXT_MAIL';   # ugh
 
-  my %lists = $self->lists();
+  my %lists = $self->lists;
   foreach my $list (keys %lists) {
     if (exists $lists{$list}{backup}) {
       $m->{backup} = $lists{$list}{backup};
@@ -411,7 +413,7 @@ sub is_list_mail {
 
     if (exists $lists{$list}{subject_RE}) {
       my $RE = $lists{$list}{subject_RE};
-      if ($m->{subject} =~ /$RE/i) {
+      if ($m->subject =~ /$RE/i) {
         $m->{list_mail} = "belonged to list `$list' via subject";
         $m->{list_mail_dest} = $dest;
         last;
@@ -420,8 +422,8 @@ sub is_list_mail {
   }
 
   if ($m->{list_mail}) {
-    if ($m->{subject} =~ /un.?subscribe\s*$/i &&
-        ! ($m->matches('from_addrs', config->me()))[0]) {
+    if ($m->subject =~ /un.?subscribe\s*$/i &&
+        ! ($m->matches('froms', config->me))[0]) {
       $m->reject_mail("someone doesn't know how to unsubscribe");
       return 1;
     }
@@ -433,7 +435,7 @@ sub is_list_mail {
   }
 
   if (($m->matches('ftc', qr/hyper\.stanford\.edu/))[0]) {
-    my $forum = $m->{header}->get('X-HN-Forum');
+    my $forum = $m->header->get('X-HN-Forum');
     chomp $forum;
 
     if ($forum eq 'PCMCIA driver beta testing') {
@@ -448,12 +450,12 @@ sub is_list_mail {
     }
     else {
       $m->accept_mail('unknown HyperNews forum');
-      $m->deliver_mail();
+      $m->deliver_to_main;
       return 1;
     }
   }
 
-  if ($m->{from} =~ /postmaster\@pdi\.com/) {
+  if ($m->from =~ /postmaster\@pdi\.com/) {
     $m->ditch_mail('cretins at pdi.com');
     return 1;
   }
@@ -472,7 +474,7 @@ sub is_list_mail {
 
     return 0 unless ($m->matches('ftc', $gg))[0];
 
-    if ($m->{subject} =~ /Faq-O-Matic Moderator Mail/) {
+    if ($m->subject =~ /Faq-O-Matic Moderator Mail/) {
       if ($m->{body_scalar} =~ /^Who:\s*aspiers\@guideguide\.com\b/m) {
         $m->ditch_mail('my Faq-O-Matic changes');
       }
@@ -502,18 +504,18 @@ sub is_list_mail {
       $m->accept_mail("gg-cvs-notify");
       $m->deliver_to("computer-work/gg-cvs-notify.%Y-%qq");
 
-      if ($m->{subject} =~ m!moo/(career|images)! ||
-          $m->{subject} =~ m!moo/gg/Modules/Foto! ||
-          $m->{subject} =~ m!moo/gg/files/xml! ||
-          $m->{subject} =~ m!moo/gg/messages! ||
-#          $m->{subject} =~ m!architekt|career|friseur|gourmet|krankenhaus|
+      if ($m->subject =~ m!moo/(career|images)! ||
+          $m->subject =~ m!moo/gg/Modules/Foto! ||
+          $m->subject =~ m!moo/gg/files/xml! ||
+          $m->subject =~ m!moo/gg/messages! ||
+#          $m->subject =~ m!architekt|career|friseur|gourmet|krankenhaus|
 #                             moebel!ix ||
-          $m->{subject} =~ m!<sybase>!)
+          $m->subject =~ m!<sybase>!)
       {
         $m->ditch_mail('uninteresting gg cvs commits');
         return 'NEXT_MAIL';
       }
-      if (($m->matches('from_addrs', config->me()))[0]) {
+      if (($m->matches('froms', config->me))[0]) {
         $m->ditch_mail('my gg cvs commits');
         return 'NEXT_MAIL';
       }
@@ -522,7 +524,7 @@ sub is_list_mail {
       return 'NEXT_MAIL';
     }
 
-    if ($m->{subject} =~ /bugzilla buglist needs attention/i) {
+    if ($m->subject =~ /bugzilla buglist needs attention/i) {
       $m->{backup} = 0;
       $m->accept_mail("gg bugzilla reminders");
       $m->deliver_to_inbox('gg-bugzilla-reminders');
@@ -537,7 +539,7 @@ sub is_from_daemon {
   my $m = shift;
   
   # known daemons
-  if (my @m = $m->matches('from_addrs',
+  if (my @m = $m->matches('froms',
                     qr/(
                         MAILER-DAEMON\@
                         (?:
@@ -554,7 +556,7 @@ sub is_from_daemon {
     return 1;
   }
 
-  if (my @m = $m->matches('from_addrs',
+  if (my @m = $m->matches('froms',
                           qr/(MAILER-DAEMON\@www\.genie\.co\.uk)/)) {
     $m->accept_mail('from SMS gateway', "`$m[1]'");
     $m->{not_to_mobile} = 1;
